package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcProcurePlan;

/**
 * 采购计划Mapper接口
 * 
 * @author cmc
 * @date 2024-09-18
 */
public interface CmcProcurePlanMapper 
{
    /**
     * 查询采购计划
     * 
     * @param procurePlanId 采购计划主键
     * @return 采购计划
     */
    public CmcProcurePlan selectCmcProcurePlanByProcurePlanId(Integer procurePlanId);

    /**
     * 查询采购计划列表
     * 
     * @param cmcProcurePlan 采购计划
     * @return 采购计划集合
     */
    public List<CmcProcurePlan> selectCmcProcurePlanList(CmcProcurePlan cmcProcurePlan);

    /**
     * 新增采购计划
     * 
     * @param cmcProcurePlan 采购计划
     * @return 结果
     */
    public int insertCmcProcurePlan(CmcProcurePlan cmcProcurePlan);

    /**
     * 修改采购计划
     * 
     * @param cmcProcurePlan 采购计划
     * @return 结果
     */
    public int updateCmcProcurePlan(CmcProcurePlan cmcProcurePlan);

    /**
     * 删除采购计划
     * 
     * @param procurePlanId 采购计划主键
     * @return 结果
     */
    public int deleteCmcProcurePlanByProcurePlanId(Integer procurePlanId);

    /**
     * 批量删除采购计划
     * 
     * @param procureApplyId 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcProcurePlanByProcureApplyIds(String[] procureApplyId);
}
